from msgspec import Struct
from typing import Literal, Union

NUMBER = Union[int, float]

class RedwoodAction:
    Allow: str = 'allow'
    Block: str = 'block'
    Ignore: str = 'ignore'
    ACL: str = 'acl'


ACTIONS = Literal['allow', 'block', 'ignore', 'acl']
RULE_TYPES = Literal['domain', 'ip', 'phrase', 'regex']


class CategoryConf(Struct):
    """
    Category config with basic keys included.
    """
    id: str
    action: ACTIONS
    genre_id: str
    rating: str
    parent_multiplier: float = 1.0


CATEGORY_CONFIGS = dict[str, CategoryConf]
CATEGORY_NAMES_SCORES = dict[str, NUMBER]
RULE_NAMES_SCORES = dict[str, NUMBER]


class RuleStat(Struct):
    Count: NUMBER
    Score: NUMBER


class ClassifierRatings:
    """
    Ratings that are used for Classifier purposes.
    """
    SILT: str = 'silt'
    SAND: str = 'sand'
    PEBBLE: str = 'pebble'
    STONE: str = 'stone'
    ROCK: str = 'rock'
    BOULDER: str = 'boulder'


class RatingCode:
    MISC: str = 'misc'
    BASE: str = 'bse'
    SILT: str = 'slt'
    SAND: str = 'snd'
    PEBBLE: str = 'pbs'
    STONE: str = 'stn'
    ROCK: str = 'rck'
    BOULDER: str = 'bld'
    ADS: str = 'ads'
    SLAG: str = 'slag'


class RatingName:
    MISC: str = 'misc'
    BASE: str = 'base'
    SILT: str = 'silt'
    SAND: str = 'sand'
    PEBBLE: str = 'pebble'
    STONE: str = 'stone'
    ROCK: str = 'rock'
    BOULDER: str = 'boulder'
    ADS: str = 'ads'
    SLAG: str = 'slag'


NON_SCORING_RATINGS = (
    RatingName.MISC,
    RatingName.BASE,
    RatingName.ADS,
    RatingName.SLAG,
)


__all__ = (
    'RedwoodAction',
    'ACTIONS',
    'RULE_TYPES',
    'CategoryConf',
    'CATEGORY_CONFIGS',
    'CATEGORY_NAMES_SCORES',
    'RuleStat',
    'RULE_NAMES_SCORES',
    'ClassifierRatings',
    'RatingCode',
    'RatingName',
    'NON_SCORING_RATINGS',
    'NUMBER',
)
